@@ -6,107 +6,126 @@
     <message>
         <location filename="../mainwindow.ui" line="14"/>
         <location filename="../mainwindow.cpp" line="302"/>
+        <location filename="../ui_mainwindow.h" line="225"/>
         <source>MX Service Manager</source>
         <translation>Gerenciador de Serviços do MX</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="62"/>
-        <source>About this application</source>
-        <translation>Sobre este aplicativo</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="26"/>
         <location filename="../mainwindow.cpp" line="157"/>
         <location filename="../mainwindow.cpp" line="317"/>
+        <location filename="../ui_mainwindow.h" line="226"/>
         <source>&amp;Enable at boot</source>
         <translation>&amp;Ativar na inicialização</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="62"/>
+        <location filename="../ui_mainwindow.h" line="228"/>
+        <source>About this application</source>
+        <translation>Sobre este aplicativo</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="65"/>
+        <location filename="../ui_mainwindow.h" line="230"/>
         <source>&amp;About...</source>
         <translation>&amp;Sobre...</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="72"/>
+        <location filename="../ui_mainwindow.h" line="232"/>
         <source>Alt+B</source>
         <translation>Alt+B</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="126"/>
+        <location filename="../ui_mainwindow.h" line="236"/>
         <source>Display help </source>
         <translation>Exibir ajuda</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="129"/>
+        <location filename="../ui_mainwindow.h" line="238"/>
         <source>&amp;Help</source>
         <translation>A&amp;juda</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="136"/>
+        <location filename="../ui_mainwindow.h" line="240"/>
+        <source>Alt+H</source>
+        <translation>Alt+H</translation>
+    </message>
+    <message>
+        <location filename="../mainwindow.ui" line="168"/>
+        <location filename="../ui_mainwindow.h" line="243"/>
+        <source>Quit application</source>
+        <translation>Sair do aplicativo</translation>
+    </message>
     <message>
         <location filename="../mainwindow.ui" line="171"/>
+        <location filename="../ui_mainwindow.h" line="245"/>
         <source>&amp;Close</source>
         <translation>&amp;Fechar</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="227"/>
-        <location filename="../mainwindow.cpp" line="278"/>
-        <source>Services enabled at boot</source>
-        <translation>O serviços foram ativados na inicialização</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="232"/>
-        <location filename="../mainwindow.cpp" line="279"/>
-        <source>Services disabled at boot</source>
-        <translation>O serviços foram desativados da inicialização</translation>
-    </message>
-    <message>
-        <location filename="../mainwindow.ui" line="268"/>
-        <source>search</source>
-        <translation>Digite aqui para pesquisar</translation>
+        <location filename="../mainwindow.ui" line="178"/>
+        <location filename="../ui_mainwindow.h" line="247"/>
+        <source>Alt+N</source>
+        <translation>Alt+N</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="203"/>
         <location filename="../mainwindow.cpp" line="139"/>
+        <location filename="../ui_mainwindow.h" line="250"/>
         <source>&amp;Stop</source>
         <translation>&amp;Parar</translation>
     </message>
-    <message>
-        <location filename="../mainwindow.ui" line="297"/>
-        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
-        <translation>Esta ferramenta lista os serviços e os processos que estão sendo executados em segundo plano (daemons) que foram encontrados neste sistema operacional. Utilize este programa com muito cuidado e evite parar a execução de determinados aplicativos que possam interromper o funcionamento de componentes críticos do sistema operacional. É melhor não interromper a execução dos aplicativos que você não sabe o que é ou não sabe para que serve.</translation>
-    </message>
     <message>
         <location filename="../mainwindow.ui" line="217"/>
+        <location filename="../ui_mainwindow.h" line="251"/>
         <source>All services</source>
         <translation>Todos os serviços</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="222"/>
         <location filename="../mainwindow.cpp" line="277"/>
+        <location filename="../ui_mainwindow.h" line="252"/>
         <source>Running services</source>
         <translation>Serviços em execução</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="136"/>
-        <source>Alt+H</source>
-        <translation>Alt+H</translation>
+        <location filename="../mainwindow.ui" line="227"/>
+        <location filename="../mainwindow.cpp" line="278"/>
+        <location filename="../ui_mainwindow.h" line="253"/>
+        <source>Services enabled at boot</source>
+        <translation>O serviços foram ativados na inicialização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="168"/>
-        <source>Quit application</source>
-        <translation>Sair do aplicativo</translation>
+        <location filename="../mainwindow.ui" line="232"/>
+        <location filename="../mainwindow.cpp" line="279"/>
+        <location filename="../ui_mainwindow.h" line="254"/>
+        <source>Services disabled at boot</source>
+        <translation>O serviços foram desativados da inicialização</translation>
     </message>
     <message>
-        <location filename="../mainwindow.ui" line="178"/>
-        <source>Alt+N</source>
-        <translation>Alt+N</translation>
+        <location filename="../mainwindow.ui" line="268"/>
+        <location filename="../ui_mainwindow.h" line="257"/>
+        <source>search</source>
+        <translation>Digite aqui para pesquisar</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="278"/>
         <location filename="../mainwindow.cpp" line="68"/>
         <location filename="../mainwindow.cpp" line="81"/>
+        <location filename="../ui_mainwindow.h" line="258"/>
         <source>Loading...</source>
         <translation>Carregando...</translation>
     </message>
+    <message>
+        <location filename="../mainwindow.ui" line="297"/>
+        <location filename="../ui_mainwindow.h" line="259"/>
+        <source>This tool lists services and daemons (processes that run in the background) found on this system. Be careful to avoid stopping something that might disrupt a critical component; best to leave it alone if you don&apos;t know what it is.</source>
+        <translation>Esta ferramenta lista os serviços e os processos que estão sendo executados em segundo plano (daemons) que foram encontrados neste sistema operacional. Utilize este programa com muito cuidado e evite parar a execução de determinados aplicativos que possam interromper o funcionamento de componentes críticos do sistema operacional. É melhor não interromper a execução dos aplicativos que você não sabe o que é ou não sabe para que serve.</translation>
+    </message>
     <message>
         <location filename="../mainwindow.cpp" line="62"/>
         <location filename="../mainwindow.cpp" line="319"/>
@@ -132,14 +151,6 @@
         <source>&amp;Disable at boot</source>
         <translation>&amp;Desativar na inicialização</translation>
     </message>
-    <message>
-        <source>%1 total services, %2 currently %3running%4</source>
-        <translation type="vanished">%1 total de serviços, %2 %3estão atualmente em execução%4</translation>
-    </message>
-    <message>
-        <source>%1 %2enabled%3 at boot, but not running</source>
-        <translation type="vanished">%1 %2estão ativos na inicialização%3, mas não está(ão) em execução</translation>
-    </message>
     <message>
         <location filename="../mainwindow.cpp" line="286"/>
         <source>%1 total services, %2 currently &lt;font color=&apos;%3&apos;&gt;running&lt;/font&gt;</source>
